GEM Gyro-fluid model
====================

6 moments for each species

"GEM - An Energy Conserving Electromagnetic Gyrofluid Model"
by Bruce D Scott. arXiv:physics/0501124v1 23 Jan 2005

This version uses global parameters for collisionality etc.
